|Version and Date       | Description           |
|-----------------------|-----------------------|
| 0.0.0<br>February 2022 | Initial commit. |
| 0.0.1<br>February 2022 | Added plotting library from util.plot and updated <br> requirements. |
| 0.0.2<br>February 2022 | Fixing pip install errors. |
| 0.0.2<br>February 2022 | Fixing pip install errors. |
| 0.0.2<br>February 2022 | Fixing pip install errors. |
| 0.0.2<br>February 2022 | Fixing pip install errors. |
| 0.0.3<br>February 2022 | Added well spaced random designs over the box and <br> ball. |
| 0.0.4<br>February 2022 | Added 'approximate' and support for generic surface <br> points in 'Plot.add_function'. |
| 0.0.5<br>March 2022 | APOS model added to library. |
